//******************************************************************************
// FILE:       	main.c
//              
// AUTHOR:     	CC Cox - SynchroSystems
//              
// PROJECT:    	SynchroChron
//              
// DESCRIPTION:	Main loop & ISR for SynchroChron LCD demonstration
//
// HISTORY:
//		$Log: main.c,v $
//		Revision 1.7  2006-01-26 12:17:14-05  chuck
//		Release candidate
//
//		Revision 1.6 2006-01-13 chuck
//		Code review changes
//
//		Revision 1.0 2005-03-15 chuck
//		Initial revision
//
// Copyright (c) 2006 SynchroSystems Inc
// Use subject to terms of License Agreement at http://synchro.com/policies.html
//******************************************************************************

//------------------------------------------------------------------------------
// include files
//------------------------------------------------------------------------------
#include "demo.h"						// project definitions

//******************************************************************************
// PRIVATE DECLARATIONS
//******************************************************************************

//------------------------------------------------------------------------------
// ROM data
//------------------------------------------------------------------------------
static const UINT8 ID[] = "$Id: main.c,v 1.7 2006-01-26 12:17:14-05 chuck Exp chuck $";		// RCS ID string

//******************************************************************************
// PUBLIC FUNCTIONS
//******************************************************************************

//------------------------------------------------------------------------------
//  FUNCTION:		main
//              
//  PARAMETERS: 	none
//              
//  RETURNS:    	nothing
//              
//  DESCRIPTION:	Main loop
//------------------------------------------------------------------------------
void main(void)
{
	//
	// initialization
	//
	Init();								// device initialization
	Demo();								// LCD demonstration routine
	assert(FALSE);						//lint !e506 unreachable code
}

//------------------------------------------------------------------------------
//  FUNCTION:   	timera_0_isr
//              
//  PARAMETERS: 	none
//              
//  RETURNS:    	nothing
//              
//  DESCRIPTION:	Timer_A CCR0 interrupt service routine
//					Interrupt flag (CCIFG) automatically cleared
//					Call high-level timer functions
//					Wakeup background code
//
//					The ISR is coded for compatibility with multiple compilers
//					For compilers that use #pragma, interrupt() is redefined
//					For compilers that use interrupt(), #pragma is ignored
//------------------------------------------------------------------------------
#pragma interrupt_handler timera_0_isr:TIMERA0_VECTOR
interrupt(TIMERA0_VECTOR) timera_0_isr(void)
{
	DemoTimer();						// high-level timer functions
	LPM3_EXIT;							// exit low power mode
}
